package main

import (
	"os"

	"gitlab.quimbo.fr/odwrtw/canape-sql/auth"
	"gitlab.quimbo.fr/odwrtw/canape-sql/movies"
	"gitlab.quimbo.fr/odwrtw/canape-sql/users"
	"gitlab.quimbo.fr/odwrtw/canape-sql/web"

	"github.com/Sirupsen/logrus"
	"github.com/codegangsta/negroni"
	"github.com/gorilla/mux"
	"github.com/jmoiron/sqlx"
	_ "github.com/lib/pq"
)

type UserBackend struct {
	Database *sqlx.DB
}

func (b *UserBackend) Get(username string) (auth.User, error) {
	return users.Get(b.Database, username)
}

func main() {
	log := logrus.NewEntry(logrus.New())

	pgdsn := "postgres://test:test@127.0.0.1:5432/test?sslmode=disable"
	db, err := sqlx.Connect("postgres", pgdsn)
	if err != nil {
		log.Error(err)
		os.Exit(1)
	}
	uBackend := &UserBackend{db}
	authorizer := auth.New(uBackend, "peeper", "cookieName", "cookieKey", 10)

	env := web.NewEnv(db, authorizer, log, "/templates")

	router := mux.NewRouter()

	router.Handle("/", env.Handler(movies.PolochonMovies))

	n := negroni.Classic()
	n.UseHandler(router)
	n.Run(":3000")
}
